/*
** Copyright (C) 2009 Tadej Borovšak <tadeboro@gmail.com>
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
** 
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
** 
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software 
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#include <glib.h>
#include <cairo.h>

/* Local functions declarations go here */
static void
transition_render( cairo_t         *cr,
				   cairo_surface_t *image_from,
				   cairo_surface_t *image_to,
				   gdouble          progress,
                   gint				type );

/* Plug-in API */
void
img_get_plugin_info( gchar  **group,
                     gchar ***trans )
{
    gint i = 0;
    *group = "Rotation";

    *trans = g_new( gchar *, 4 );

    (*trans)[i++] = "Rotating Square";
    (*trans)[i++] = "img_square";
    (*trans)[i++] = GINT_TO_POINTER( 5000 );

    (*trans)[i++] = NULL;
}

void
img_square( cairo_t         *cr,
			cairo_surface_t *image_from,
			cairo_surface_t *image_to,
			gdouble          progress )
{
    transition_render( cr, image_from, image_to, progress, 1 );
}

/* Local functions definitions */
static void
transition_render( cairo_t         *cr,
				   cairo_surface_t *image_from,
				   cairo_surface_t *image_to,
				   gdouble          progress,
                   gint				type )
{
    gint    width, height;
	gdouble speed = 1;

	width  = cairo_image_surface_get_width( image_from );
	height = cairo_image_surface_get_height( image_from );

    /* Drawing code goes here */
	cairo_set_source_surface( cr, image_from, 0, 0 );
	cairo_paint( cr );

	cairo_set_source_surface( cr, image_to, 0, 0 );
	cairo_translate( cr, width / 2, height / 2 );
	cairo_rotate( cr, G_PI * progress * speed );
	cairo_rectangle( cr, - width / 2 * progress, - height / 2 * progress,
					 width * progress, height * progress );
	cairo_fill( cr );
}
